from django.apps import AppConfig


class ViewBreadcrumbsConfig(AppConfig):
    name = "view_breadcrumbs"
